---
jupytext:
  formats: md:myst
  text_representation:
    extension: .md
    format_name: myst
kernelspec:
  display_name: Python 3
  language: python
  name: python
---

# Introduction

This is the documentation for `fwdpy11`, a Python package for individual-based, forward-time simulations of population genetic processes.

## Version

This manual is built with the following version of `fwdpy11`:

```{code-cell} python
---
tags: ["hide-input"]
---
import fwdpy11
fwdpy11.__version__
```

## How to read this documentation

The documentation is organized around a number of short vignettes.
We recommend that new users start there, and read them in order.

Longer-form pages follow the vignettes.
These contain more in the way of technical details that are probably best skipped upon a first reading of this manual.

Many of the vignettes contain executable code.
You may download any of these chapters as Jupyter notebooks and work with them locally.
Doing so requires that `fwdpy11` is installed on your system.

